PaddingBlock class

FLAC PADDING metadata block.

Contains only zero bytes; used to allow in-place editing of metadata without rewriting the audio data.

Inheritance

Constructors

PaddingBlock({required bool isLast, required int length})
const

Properties

blockType int
The block type identifier (see BlockType).
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isLast bool
Whether this is the last metadata block before the audio frames.
finalinherited
length int
The length of the block data in bytes (excluding the 4-byte header).
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(bool isLast, int length, Uint8List data) PaddingBlock
Parses a PaddingBlock from its raw data bytes.