SeekTableBlock class
FLAC SEEKTABLE metadata block.
Contains an ordered list of seek points that allow efficient random access into the audio stream.
- Inheritance
-
- Object
- MetadataBlock
- SeekTableBlock
Constructors
-
SeekTableBlock({required bool isLast, required int length, required List<
SeekPoint> seekPoints}) -
const
Properties
- blockType → int
-
The block type identifier (see BlockType).
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLast → bool
-
Whether this is the last metadata block before the audio frames.
finalinherited
- length → int
-
The length of the block data in bytes (excluding the 4-byte header).
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
seekPoints
→ List<
SeekPoint> -
The seek points in ascending order of SeekPoint.sampleNumber.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
bool isLast, int length, Uint8List data) → SeekTableBlock -
Parses a SeekTableBlock from its raw
databytes.