UnknownMetadataBlock class
A metadata block whose type is not recognised by this library version.
- Inheritance
-
- Object
- MetadataBlock
- UnknownMetadataBlock
Constructors
- UnknownMetadataBlock({required int blockType, required bool isLast, required int length, required Uint8List rawData})
-
const
Properties
- blockType → int
-
The block type identifier (see BlockType).
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLast → bool
-
Whether this is the last metadata block before the audio frames.
finalinherited
- length → int
-
The length of the block data in bytes (excluding the 4-byte header).
finalinherited
- rawData → Uint8List
-
The raw bytes of this block's data section.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited